@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 1998, 2019 IBM Corp. and others
+ * Copyright (c) 1998, 2020 IBM Corp. and others
  *
  * This program and the accompanying materials are made available under
  * the terms of the Eclipse Public License 2.0 which accompanies this
@@ -32,7 +32,6 @@ import jdk.internal.misc.Unsafe;
 import jdk.internal.misc.SharedSecrets;
 import jdk.internal.misc.VM;
 import java.lang.StackWalker.Option;
-import java.lang.Module;
 import jdk.internal.reflect.Reflection;
 import jdk.internal.reflect.CallerSensitive;
 import java.util.*;
@@ -334,6 +333,8 @@ private static void ensureProperties(boolean isInitialization) {
 	systemProperties = initializedProperties;
 
 	java.lang.VersionProps.init();
+	/* Preload system property jdk.serialFilter to prevent later modification */
+	jdk.internal.util.StaticProperty.jdkSerialFilter();
 
 	String javaRuntimeVersion = initializedProperties.getProperty("java.runtime.version"); //$NON-NLS-1$
 	if (null != javaRuntimeVersion) {
@@ -357,7 +358,7 @@ private static void ensureProperties(boolean isInitialization) {
 
 /* Converts a Map<String, String> to a properties object.
  * 
- * The sytem properties will be initialized as a Map<String, String> type to be compatible
+ * The system properties will be initialized as a Map<String, String> type to be compatible
  * with jdk.internal.misc.VM and java.lang.VersionProps APIs.
  */
 private static void initializeSystemProperties(Map<String, String> mapProperties) {
@@ -679,13 +680,11 @@ public static void setSecurityManager(final SecurityManager s) {
 						// also load security sensitive classes 
 						com.ibm.oti.util.Msg.getString("K002c"); //$NON-NLS-1$
 					}
-					ProtectionDomain oldDomain = currentSecurity == null ?
-						System.class.getPDImpl() : currentSecurity.getClass().getPDImpl();
-					ProtectionDomain newDomain = s.getClass().getPDImpl();
-					if (oldDomain != newDomain) {
+					ProtectionDomain pd = s.getClass().getPDImpl();
+					if (pd != null) {
 						// initialize the protection domain, which may include preloading the
 						// dynamic permissions from the policy before installing
-						newDomain.implies(new AllPermission());
+						pd.implies(sun.security.util.SecurityConstants.ALL_PERMISSION);
 					}
 					return null;
 				}});
@@ -1194,12 +1193,34 @@ public interface Logger {
 	 * System loggers levels
 	 */
 	public enum Level {
+		/**
+		 * Enable all logging level messages
+		 */
 		ALL(Integer.MIN_VALUE),
+		/**
+		 * Enable TRACE level messages
+		 */
 		TRACE(400),
+		/**
+		 * Enable DEBUG level messages
+		 */
 		DEBUG(500),
+		/**
+		 * Enable INFO level messages
+		 */
 		INFO(800),
+		/**
+		 * Enable WARNING level messages
+		 */
 		WARNING(900),
+		/**
+		 * Enable ERROR level messages
+		 */
 		ERROR(1000),
+		/**
+		 *
+		 * Disable logging 
+		 */
 		OFF(Integer.MAX_VALUE);
 		
 		final int severity;
