@@ -90,12 +90,11 @@ final class SunEntries {
     /*
      * Check whether native crypto is enabled with property.
      * By default, the native crypto is enabled and uses native library crypto.
-     * The native crypto for MessageDigest is disabled until
-     * https://github.com/eclipse/openj9/issues/5611 can be resolved.
-     * The property 'jdk.nativeCrypto' is used to disable all native cryptos (Digest,
+     * The property 'jdk.nativeDigest' is used to disable Native digest alone
+     * and 'jdk.nativeCrypto' is used to disable all native cryptos (Digest,
      * CBC, GCM, RSA, and ChaCha20).
      */
-    private static boolean useNativeDigest = false;
+    private static boolean useNativeDigest = true;
 
     private SunEntries() {
         // empty
